@@ -31,7 +31,7 @@ private:
         return -1;
     }
 
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         Q_INIT_RESOURCE(schematemplates);
