@@ -21,7 +21,7 @@ using namespace KUserFeedback::Console;
 class SchemaModelTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         Q_INIT_RESOURCE(schematemplates);
